==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/language/1/am_default/my_profile.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


require_once($languagePath . 'my_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_profile'] = 							"profile";
$lang['hdr_profiles'] = 						"profiles";
$lang['hdr_summary'] = 							"summary";
$lang['hdr_images'] = 							"images";
$lang['hdr_group_usage'] = 						"group profile usage";
$lang['hdr_degree_usage'] = 					"social network profile usage";
$lang['hdr_publishing'] = 						"publishing";


//SUBMIT BUTTONS
$lang['sub_update'] = 							"update";
$lang['sub_insert'] = 							"insert";
$lang['sub_update_default_profile'] = 			"update default profile";
$lang['sub_update_degree_profile'] = 			"set network profiles";


//HREF
$lang['href_list'] = 							"list profiles";
$lang['href_add_profile'] = 					"add profile";


//ERR
$lang['err_no_profiles'] = 						"Sorry, you have no profiles.";
$lang['err_no_profile_usage'] = 				"Sorry, you have not used your profiles yet.";


//BODY TEXT
$lang['txt_profile_name'] = 					"profile name";
$lang['txt_profile_nic'] = 						"nickname (nic)";
$lang['txt_profile_create_datetime'] = 			"create date";
$lang['txt_profile_hometown'] = 				"hometown";
$lang['txt_profile_msn_account'] =				"microsoft messenger (MSN) ID";
$lang['txt_profile_yahoo_account'] =			"Yahoo ID";
$lang['txt_profile_icq_account'] =				"ICQ number";
$lang['txt_summary'] =							"summary";
$lang['txt_images_help'] = 						"Select an image if you want one to appear next to your profile.";
$lang['txt_profile_skype_account'] = 			"skype";
$lang['txt_profile_mobile_phone'] = 			"mobile phone";
$lang['txt_no_delete'] = 						"You cannot delete a profile that is in use or that is set as your default profile.";
$lang['txt_gender'] = 							"gender";
$lang['txt_female'] = 							"female";
$lang['txt_male'] = 							"male";
$lang['txt_none'] = 							"none";
$lang['txt_allow_comments'] =					"check to allow anyone comments";
$lang['txt_profiles_intro'] = 					"Profiles are a summary of you that you choose to display to someone when they see you in this community. You can create different profiles to display to different social networking degrees and different groups. For instance you may choose to make a profile with all you contact details that only your friends can see and a professional 'cv' profile for groups. Your default profile is the profile that is seen by everyone outside of your social network and in all lists. We recommend that this profile contains no contact information.";
$lang['txt_profile_allow_msg'] = 				"check to allow receipt of messages";

$lang['txt_comment_allow'] =					"comments are allowed to be left by people viewing this profile.";
$lang['txt_comment_deny'] =						"comments are not allowed to be left by people viewing this profile.";

$lang['txt_msg_allow'] =						"people viewing this profile are allowed to send you aroundme messages.";
$lang['txt_msg_deny'] =							"people viewing this profile are not allowed to send you aroundme messages.";

$lang['txt_profile_edit_intro'] = 				"We recomomend that nicknames used within your social network are the same as your default profile nickname for consistency. Please ensure your nickname is correct. In future editions of aroundme you will reduce you standing in the community by changing your nickname.";

?>

==> aroundme_0_4_3.zip: aroundme_0_4_3/www/aroundme_0_4_3/language/1/am_default/my_profile.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


require_once($languagePath . 'my_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_profile'] = 							"profile";
$lang['hdr_profiles'] = 						"profiles";
$lang['hdr_summary'] = 							"summary";
$lang['hdr_images'] = 							"images";
$lang['hdr_group_usage'] = 						"group profile usage";
$lang['hdr_degree_usage'] = 					"social network profile usage";
$lang['hdr_publishing'] = 						"publishing";


//SUBMIT BUTTONS
$lang['sub_update'] = 							"update";
$lang['sub_insert'] = 							"insert";
$lang['sub_update_default_profile'] = 			"update default profile";
$lang['sub_update_degree_profile'] = 			"set network profiles";


//HREF
$lang['href_list'] = 							"list profiles";
$lang['href_add_profile'] = 					"add profile";


//ERR
$lang['err_no_profiles'] = 						"Sorry, you have no profiles.";
$lang['err_no_profile_usage'] = 				"Sorry, you have not used your profiles yet.";



//PROFILE ADDONS
// leave these blank if you do not want them to show in forms and on pages.
$lang['txt_profile_text1'] =					"microsoft messenger (MSN) ID";
$lang['txt_profile_text2'] =					"Yahoo ID";
$lang['txt_profile_text3'] =					"ICQ number";
$lang['txt_profile_text4'] = 					"mobile phone";
$lang['txt_profile_text5'] = 					"skype";
$lang['txt_profile_text6'] = 					"job title";
$lang['txt_profile_text7'] = 					"";
$lang['txt_profile_text8'] = 					"";
$lang['txt_profile_text9'] = 					"";
$lang['txt_profile_text10'] = 					"";


//BODY TEXT
$lang['txt_profile_name'] = 					"profile name";
$lang['txt_profile_nic'] = 						"nickname (nic)";
$lang['txt_profile_create_datetime'] = 			"create date";
$lang['txt_profile_hometown'] = 				"hometown";
$lang['txt_summary'] =							"summary";
$lang['txt_images_help'] = 						"Select an image if you want one to appear next to your profile.";
$lang['txt_no_delete'] = 						"You cannot delete a profile that is in use or that is set as your default profile.";
$lang['txt_gender'] = 							"gender";
$lang['txt_female'] = 							"female";
$lang['txt_male'] = 							"male";
$lang['txt_none'] = 							"undisclosed";
$lang['txt_allow_comments'] =					"check to allow anyone comments";
$lang['txt_profiles_intro'] = 					"Profiles are a summary of you that you choose to display to someone when they see you in this community. You can create different profiles to display to different social networking degrees and different groups. For instance you may choose to make a profile with all you contact details that only your friends can see and a professional 'cv' profile for groups. Your default profile is the profile that is seen by everyone outside of your social network and in all lists. We recommend that this profile contains no contact information.";
$lang['txt_profile_allow_msg'] = 				"check to allow receipt of messages";
$lang['txt_comment_allow'] =					"comments are allowed to be left by people viewing this profile.";
$lang['txt_comment_deny'] =						"comments are not allowed to be left by people viewing this profile.";
$lang['txt_msg_allow'] =						"people viewing this profile are allowed to send you aroundme messages.";
$lang['txt_msg_deny'] =							"people viewing this profile are not allowed to send you aroundme messages.";
$lang['txt_profile_edit_intro'] = 				"We recomomend that nicknames used within your social network are the same as your default profile nickname for consistency. Please ensure your nickname is correct. In future editions of aroundme you will reduce you standing in the community by changing your nickname.";

?>
